/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hop.pipeline.transform;

import org.apache.hop.metadata.api.IHopMetadataProvider;

/**
 * This interface is used to launch Transform Dialogs. All dialogs that implement this simple
 * interface can be opened by HopGui.
 */
public interface ITransformDialog {

  /**
   * Opens a transform dialog window.
   *
   * @return the (potentially new) name of the transform
   */
  String open();

  /**
   * Brings the dialog to the front if the dialog is already open.
   */
  void setActive();
  
  /**
   * void populateComposite( Composite parent);
   *
   * <p>/**
   *
   * @param metadataProvider The MetaStore to pass
   */
  void setMetadataProvider(IHopMetadataProvider metadataProvider);
}
